AnnotationTarget class

Constructors

AnnotationTarget({required String uri, required int offset, required int length, required int line, required int column, required String symbolName, required String kind})
const

Properties

column int
final
hashCode int
The hash code for this object.
no setterinherited
kind String
final
length int
final
line int
final
offset int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
symbolName String
final
uri String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited